proc Cmas2d::WriteCalculationFile { filename } {

customlib::InitWriteFile $filename

set xp1 {container[@n="Properties"]/condition[@n="Shells"]/group}
set xp2 ".//value\[@n='material']"

# We will save a TCL dictionary with the information requested (materials & beam information)
set mat_dict ""
set material_number 0
set formats ""

set root [$::gid_groups_conds::doc documentElement]
foreach gNode [$root selectNodes $xp1] {
set valueNode [$gNode selectNodes $xp2]
set material_name [get_domnode_attribute $valueNode v]
if { ![dict exists $mat_dict $material_name] } {
incr material_number
set mid $material_number

#We also save the density of the material by checking the material database
set xp3 {/*/container[@n="Properties"]/container[@n="materials"]//}
append xp3 [format_xpath {blockdata[@n="material" and @name=%s]/value[@n="Density"]} $material_name]
set valueNode [$root selectNodes $xp3]
# All the introduced values are translated to 'm' and 'kg' with the help of this function
set density [gid_groups_conds::convert_value_to_default $valueNode]

dict set mat_dict $material_name MID $material_number
dict set mat_dict $material_name DENSITY [format "%13.5E" $density]
} else {
set mid [dict get $mat_dict $material_name MID]
}
set f {\n%10d %10d %10d %10d [format "%10d" $mid]}
set f [subst $f]
dict set formats [$gNode @n] $f
}

if {$material_number=="0"} {
error [= "Remember to define your surface/s as shell/s"]
}

customlib::WriteString "bb:"
# Beams applied on lines
set xp3 {//condition[@n="beam"]/group}
foreach gNode [$root selectNodes $xp3] {
customlib::WriteString "node: $gNode"
set valueNode [$gNode selectNodes {value[@n="beamV"]}]
set weight [gid_groups_conds::convert_value_to_default $valueNode]
set f {\n%10d %10d %10d $weight}
set f [subst $f]
dict set formats [$gNode @n] $f
customlib::WriteString "beamV: $weight"
}

customlib::WriteString "formats: $formats"

customlib::WriteString "Liner:"
GiD_WriteCalculationFile all_connectivities -elemtype Linear "id: %d connnectivities: %d %d\n"
customlib::WriteString "Triangle:"
GiD_WriteCalculationFile all_connectivities -elemtype Triangle "id: %d connnectivities: %d %d %d\n"
customlib::WriteString "Tetrahedra:"
GiD_WriteCalculationFile all_connectivities -elemtype Tetrahedra "id: %d connnectivities: %d %d %d %d\n"


customlib::WriteString "WriteConnectivities:"

set condition_name [list "beam"]
set condition_formats [list {"%3d" "element" "id"}  {"%13.5e" "property" "beamV"}]
set formats [customlib::GetElementsFormats $condition_name $condition_formats]
customlib::WriteString $formats
set number_of_elements [GiD_WriteCalculationFile elements -count -elemtype Linear $formats]
customlib::WriteString "number of elements = $number_of_elements"
GiD_WriteCalculationFile elements -elemtype Linear $formats







customlib::EndWriteFile ;#finish writting
}

